@@ -54,6 +54,7 @@
  #
  # Originally developed by Gregory Trubetskoy.
  #
+ # $Id: apache.py,v 1.68 2003/02/28 04:55:15 grisha Exp $
 
 import sys
 import traceback
@@ -126,9 +127,6 @@ class CallBack:
                     newpath = eval(pathstring)
                     if sys.path != newpath:
                         sys.path[:] = newpath
-            else:
-                if filter.dir not in sys.path:
-                    sys.path[:0] = [filter.dir]
 
             # import module
             module = import_module(module_name, config)
@@ -162,7 +160,6 @@ class CallBack:
             # Any other rerror (usually parsing)
             try:
                 exc_type, exc_value, exc_traceback = sys.exc_info()
-                filter.disable()
                 result = self.ReportError(exc_type, exc_value, exc_traceback, srv=conn.base_server,
                                           phase=filter.name, hname=handler, debug=debug)
             finally:
@@ -207,7 +204,7 @@ class CallBack:
                     if sys.path != newpath:
                         sys.path[:] = newpath
             else:
-                if filter.dir not in sys.path:
+                if filter.dir and (filter.dir not in sys.path):
                     sys.path[:0] = [filter.dir]
 
             # import module
@@ -316,7 +313,7 @@ class CallBack:
                             sys.path[:] = newpath
                 else:
                     dir = hlist.directory
-                    if dir not in sys.path:
+                    if dir and (dir not in sys.path):
                         sys.path[:0] = [dir]
 
                 # import module
@@ -723,6 +720,8 @@ class CGIStdout(NullIO):
                     else:
                         self.req.headers_out.add(h, v)
 
+                self.headers_sent = 1
+
                 # write the body if any at this point
                 self.req.write(ss[1])
         else:
@@ -761,7 +760,7 @@ def restore_nocgi(sav_env, si, so):
     osenv = os.environ
 
     # restore env
-    for k in osenv:
+    for k in osenv.keys():
         del osenv[k]
     for k in sav_env:
         osenv[k] = env[k]
